@@ -1,10 +1,10 @@
 import requests
 
-from kikyopp.utils.constants import YURI_API_HOST
+from kikyopp.utils.constants import YURI_API_HOST, RETRY_API_TIMES
 from kikyopp.utils.retry import retry_rest_api
 
 
-@retry_rest_api
+@retry_rest_api(RETRY_API_TIMES)
 def predict_bm_domain(content: str) -> list:
     resp = requests.post(
         f'{YURI_API_HOST}/bm-domain/api/predict-bm-domain',
@@ -15,7 +15,7 @@ def predict_bm_domain(content: str) -> list:
     return resp.json()['result']
 
 
-@retry_rest_api
+@retry_rest_api(RETRY_API_TIMES)
 def extract_keywords(content: str) -> list:
     resp = requests.post(
         f'{YURI_API_HOST}/keywords/api/tag/keywords',
@@ -26,7 +26,7 @@ def extract_keywords(content: str) -> list:
     return resp.json()['keywords']
 
 
-@retry_rest_api
+@retry_rest_api(RETRY_API_TIMES)
 def predict_themes(content: str) -> list:
     resp = requests.post(
         f'{YURI_API_HOST}/theme/api/tag/themes',
@@ -37,7 +37,7 @@ def predict_themes(content: str) -> list:
     return resp.json()['result']
 
 
-@retry_rest_api
+@retry_rest_api(RETRY_API_TIMES)
 def content_ner(content: str) -> dict:
     resp = requests.post(
         f'{YURI_API_HOST}/content-ner/api/ner',
