@@ -12,7 +12,8 @@ from fitz import Pixmap
 from pydantic import BaseModel
 from requests_toolbelt import MultipartEncoder
 
-from kikyopp.utils.constants import YURI_API_HOST, TIKA_HOST, PADDLEOCR_HOST, PDF_CONVERTER_HOST, FILE_CONTENT_LIMIT
+from kikyopp.utils.constants import YURI_API_HOST, TIKA_HOST, PADDLEOCR_HOST, PDF_CONVERTER_HOST, FILE_CONTENT_LIMIT, \
+    RETRY_API_TIMES
 from kikyopp.utils.retry import retry_rest_api
 
 
@@ -40,7 +41,7 @@ def pdf_to_png(data: bytes, limit: Optional[int] = None) -> List[bytes]:
     return pdf_to_image(data, limit=limit)
 
 
-@retry_rest_api
+@retry_rest_api(RETRY_API_TIMES)
 def download_file_from_bus(file_id: str) -> bytes:
     resp = requests.get(
         f'{YURI_API_HOST}/filebus/download',
@@ -53,7 +54,7 @@ def download_file_from_bus(file_id: str) -> bytes:
     return resp.content
 
 
-@retry_rest_api
+@retry_rest_api(RETRY_API_TIMES)
 def download_by_file_link(file_link: str) -> bytes:
     resp = requests.get(
         file_link,
@@ -63,19 +64,28 @@ def download_by_file_link(file_link: str) -> bytes:
     return resp.content
 
 
-@retry_rest_api
+@retry_rest_api(RETRY_API_TIMES)
 def extract_content(source: bytes) -> Optional[str]:
     resp = requests.put(
         f'{TIKA_HOST}/tika',
         data=source,
         timeout=20,
+        headers={'Accept': 'text/plain'}
     )
     resp.raise_for_status()
     return resp.content.decode('utf-8')
 
 
-@retry_rest_api
 def extract_content_by_ocr(source: bytes) -> Optional[str]:
+    res = ocr(source)
+    t = []
+    for r in res:
+        t.append(r['text'])
+    return ''.join(t)
+
+
+@retry_rest_api(RETRY_API_TIMES)
+def ocr(source: bytes) -> Optional[List[dict]]:
     image = base64.b64encode(source).decode('utf8')
     data = {"images": [image]}
     resp = requests.post(
@@ -85,10 +95,7 @@ def extract_content_by_ocr(source: bytes) -> Optional[str]:
     )
     resp.raise_for_status()
     res = resp.json()['results'][0]
-    t = []
-    for r in res:
-        t.append(r['text'])
-    return ''.join(t)
+    return res
 
 
 content_file_ext = {
@@ -102,7 +109,7 @@ content_file_ext = {
 }
 
 
-@retry_rest_api
+@retry_rest_api(RETRY_API_TIMES)
 def doc_to_pdf(source: bytes, filename: str = None) -> Optional[bytes]:
     data = None
     if filename:
@@ -124,7 +131,7 @@ def doc_to_pdf(source: bytes, filename: str = None) -> Optional[bytes]:
     return resp.content
 
 
-@retry_rest_api
+@retry_rest_api(RETRY_API_TIMES)
 def extract_file_meta(source: bytes) -> dict:
     resp = requests.put(
         f'{TIKA_HOST}/meta',
